# -*- coding: utf-8 -*-
"""
Django settings for dic-quo project.

Generated by 'django-admin startproject' using Django 3.1.1.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

import socket
from pathlib import Path
if socket.gethostname() == 'seremin':
    # офисный комп (Windows)
    from dicquo.my_secret_dev_office_win import *
elif socket.gethostname() == 'erjemin-home':
    # домашний комп (Windows)
    from dicquo.my_secret_dev_home_win import *
elif socket.gethostname() in ['m1.N1', 'm1.local', ]:
    # домашний комп (MacOS)
    from dicquo.my_secret_dev_home_mac import *
elif socket.gethostname() in ['orangepi5', 'vm678195', ]:
    # продакшн (боевой) сервер
    from dicquo.my_secret_prod import *

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = MY_SECRET_KEY

DEBUG = MY_DEBUG

ALLOWED_HOSTS = MY_ALLOWED_HOSTS

#########################################
# Настройки сообщений об ошибках когда все упало и т.п.
ADMINS = MY_ADMINS

#########################################
# настройки для почтового сервера
EMAIL_HOST = MY_EMAIL_HOST                    # SMTP server
EMAIL_PORT = MY_EMAIL_PORT                   # для SSL/https
EMAIL_HOST_USER = MY_EMAIL_HOST_USER            # login or ''
EMAIL_HOST_PASSWORD = MY_EMAIL_HOST_PASSWORD    # password
SERVER_EMAIL = DEFAULT_FROM_EMAIL = EMAIL_HOST_USER
EMAIL_USE_TLS = MY_EMAIL_USE_TLS
EMAIL_FROM = MY_EMAIL_FROM  # мейл, от имени которого отправляются письма
EMAIL_SUBJECT_PREFIX = '[DIC-QUO ERR]: '  # префикс для оповещений об ошибках и необработанных исключениях

# Application definition
INSTALLED_APPS: list[str] = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'taggit.apps.TaggitAppConfig',
    'web.apps.WebConfig',
]

MIDDLEWARE: list[str] = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF: str = 'dicquo.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [BASE_DIR / 'templates'],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'dicquo.wsgi.application'


# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator', },
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator', },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator', },
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator', },
]


# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/
LANGUAGE_CODE = 'ru-RU'         # <--------- RUSSIAN
TIME_ZONE = 'Europe/Moscow'     #
# TIME_ZONE = 'America/Los_Angeles'     #
USE_I18N = True
USE_L10N = True
USE_TZ = True               # учитывать часовой пояс
FIRST_DAY_OF_WEEK = 1       # неделя начинается с понедельника
# APPEND_SLASH = False


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.1/howto/static-files/

STATIC_URL = '/static/'
MEDIA_URL = '/media/'

# Настройки для прода....
TOUCH_RELOAD = MY_TOUCH_RELOAD   # дёргаем этот файл, чтобы перегрузить uWSGI

MEDIA_ROOT = MY_MEDIA_ROOT
STATICFILES_DIRS = [
    MY_STATIC_ROOT,
]
# STATIC_ROOT = MY_STATIC_ROOT
# STATIC_BASE_PATH = MY_STATIC_ROOT


DATABASES = {
    'default': {
        'ENGINE': "django.db.backends.mysql",
        'HOST': MY_DATABASE_HOST,  # Set to "" for localhost. Not used with sqlite3.
        'PORT': MY_DATABASE_PORT,  # Set to "" for default. Not used with sqlite3.
        'NAME': MY_DATABASE_NAME,  # Not used with sqlite3.
        'USER': MY_DATABASE_USER,  # Not used with sqlite3.
        'PASSWORD': MY_DATABASE_PASSWORD,  # Not used with sqlite3.
        # 'OPTIONS': { 'autocommit': True, }
    }
}

DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'